| Rhpc_EvalQ | R Documentation |
Evaluates an R expression on all worker processes.
Rhpc_EvalQ(cl, expr,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE),
envir = .GlobalEnv)
cl |
external pointer to MPI communicator |
expr |
expression to evaluate on workers |
usequote |
logical; if |
envir |
environment in which to evaluate the expression on workers (default: global environment) |
This function evaluates the given expression on all worker processes and returns the results. It is useful for initialization tasks or querying worker state.
Results of evaluating the expression on all workers.
Rhpc_worker_call, Rhpc_Export
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.