Rhpc_enquote: Quote arguments for remote evaluation

View source: R/RhpcOp.R

Rhpc_enquoteR Documentation

Quote arguments for remote evaluation

Description

Quotes arguments for use in remote function calls on worker processes.

Usage

Rhpc_enquote(...)

Arguments

...

arguments to be quoted

Details

This function quotes its arguments to prevent premature evaluation in the master process. The quoted expressions are then evaluated on the worker processes where they have access to the worker's data and environment.

This is primarily an internal utility; users typically do not need to call it directly.

Value

A quoted representation of the arguments suitable for remote evaluation.

See Also

Rhpc_worker_call, Rhpc_EvalQ


Rhpc documentation built on Aug. 4, 2026, 1:07 a.m.