Rhpc_getHandle: Get MPI communicator handle

View source: R/Rhpc.R

Rhpc_getHandleR Documentation

Get MPI communicator handle

Description

Obtains a handle to the MPI communicator for worker processes.

Usage

Rhpc_getHandle(procs = NA)

Arguments

procs

number of processes to create via dynamic process generation. If NA (default), uses static configuration.

Details

This function returns an external pointer to the MPI communicator, which is used in all subsequent Rhpc function calls. It also initializes the random number generation stream for workers.

If procs is specified, dynamic process generation is used (MPI_Comm_spawn). If procs is NA, static worker configuration is assumed.

Value

An external pointer to the MPI communicator handle, which can be passed to other Rhpc functions.

See Also

Rhpc_initialize, Rhpc_numberOfWorker, Rhpc_finalize


Rhpc documentation built on Aug. 4, 2026, 1:07 a.m.