Rhpc_initialize: Initialize MPI environment

View source: R/Rhpc.R

Rhpc_initializeR Documentation

Initialize MPI environment

Description

Initializes the MPI environment for Rhpc.

Usage

Rhpc_initialize()

Details

This function must be called before any other Rhpc functions to initialize the MPI communicator. It sets up the MPI environment and prepares the system for distributed computation.

Value

Returns invisibly. MPI initialization results are stored internally.

See Also

Rhpc_finalize, Rhpc_getHandle


Rhpc documentation built on Aug. 4, 2026, 1:07 a.m.