| Rhpc_Export | R Documentation |
Sends R objects from the master process to all worker processes.
Rhpc_Export(cl, variableNames,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE),
pos = 1,
envir = as.environment(pos))
cl |
external pointer to MPI communicator |
variableNames |
character vector of object names to export |
usequote |
logical; if |
pos |
environment position from which to retrieve objects (default: global environment) |
envir |
environment from which to retrieve objects (default: environment at position |
This function retrieves objects from the master's environment and sends them to all worker processes, making them available in the workers' global environment.
Objects are sent via collective communication.
Returns invisibly. Objects are assigned in worker environments.
Rhpc_worker_call, Rhpc_EvalQ
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.