| Rhpc_enquote | R Documentation |
Quotes arguments for use in remote function calls on worker processes.
Rhpc_enquote(...)
... |
arguments to be quoted |
This function quotes its arguments to prevent premature evaluation in the master process. The quoted expressions are then evaluated on the worker processes where they have access to the worker's data and environment.
This is primarily an internal utility; users typically do not need to call it directly.
A quoted representation of the arguments suitable for remote evaluation.
Rhpc_worker_call, Rhpc_EvalQ
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.