| Rhpc_getHandle | R Documentation |
Obtains a handle to the MPI communicator for worker processes.
Rhpc_getHandle(procs = NA)
procs |
number of processes to create via dynamic process generation. If |
This function returns an external pointer to the MPI communicator, which is used in all subsequent Rhpc function calls. It also initializes the random number generation stream for workers.
If procs is specified, dynamic process generation is used (MPI_Comm_spawn).
If procs is NA, static worker configuration is assumed.
An external pointer to the MPI communicator handle, which can be passed to other Rhpc functions.
Rhpc_initialize, Rhpc_numberOfWorker, Rhpc_finalize
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.