| Rhpc_initialize | R Documentation |
Initializes the MPI environment for Rhpc.
Rhpc_initialize()
This function must be called before any other Rhpc functions to initialize the MPI communicator. It sets up the MPI environment and prepares the system for distributed computation.
Returns invisibly. MPI initialization results are stored internally.
Rhpc_finalize, Rhpc_getHandle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.