Learn R Programming

Rhpc (version 0.26.5)

Rhpc_initialize: Initialize MPI environment

Description

Initializes the MPI environment for Rhpc.

Usage

Rhpc_initialize()

Arguments

Value

Returns invisibly. MPI initialization results are stored internally.

Details

This function must be called before any other Rhpc functions to initialize the MPI communicator. It sets up the MPI environment and prepares the system for distributed computation.

See Also

Rhpc_finalize, Rhpc_getHandle