| Rhpc_lapply | R Documentation |
MPI-based version of lapply that distributes work across worker processes sequentially.
Rhpc_lapply(cl, X, FUN, ...,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE))
cl |
external pointer to MPI communicator |
X |
vector or list to be processed |
FUN |
function to apply to each element of |
... |
additional arguments passed to |
usequote |
logical; if |
This function distributes elements of X sequentially to worker processes.
The input X is divided among workers and each worker processes its portion in order.
Results are collected and returned in a list maintaining the original order.
A list with results from applying FUN to each element of X.
Rhpc_lapplyLB, Rhpc_sapply, Rhpc_apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.