| Rhpc_lapplyLB | R Documentation |
MPI-based version of lapply with load balancing for better performance on heterogeneous systems.
Rhpc_lapplyLB(cl, X, FUN, ...,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE))
cl |
external pointer to MPI communicator |
X |
vector or list to be processed |
FUN |
function to apply to each element of |
... |
additional arguments passed to |
usequote |
logical; if |
This function distributes work to workers using a load-balancing approach. Workers receive tasks dynamically as they become available, which can provide better performance when task execution times vary significantly.
Results are collected and returned in a list maintaining the original order.
A list with results from applying FUN to each element of X.
Rhpc_lapply, Rhpc_sapplyLB, Rhpc_apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.