| Rhpc_sapply | R Documentation |
MPI-based version of sapply that distributes work across worker processes.
Rhpc_sapply(cl = NULL, X, FUN, ...,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE),
simplify = TRUE,
USE.NAMES = TRUE)
cl |
external pointer to MPI communicator |
X |
vector or list to be processed |
FUN |
function to apply to each element of |
... |
additional arguments passed to |
usequote |
logical; if |
simplify |
logical or character string; if possible, simplify the result to a vector or matrix |
USE.NAMES |
logical; if |
This function combines the functionality of Rhpc_lapply with automatic simplification of results.
When possible, results are simplified to a vector or matrix form rather than remaining as a list.
A simplified version of the result (vector, matrix, or array) or list depending on simplify parameter.
Rhpc_sapplyLB, Rhpc_lapply, Rhpc_apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.