| Rhpc_sapplyLB | R Documentation |
MPI-based version of sapply with load balancing for better performance.
Rhpc_sapplyLB(cl = NULL, X, FUN, ...,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE),
simplify = TRUE,
USE.NAMES = TRUE)
cl |
external pointer to MPI communicator |
X |
vector or list to be processed |
FUN |
function to apply to each element of |
... |
additional arguments passed to |
usequote |
logical; if |
simplify |
logical or character string; if possible, simplify the result |
USE.NAMES |
logical; if |
This function combines load-balanced distribution with result simplification. Workers receive tasks dynamically as they become available, and results are simplified when possible.
A simplified version of the result (vector, matrix, array, or list) depending on simplify.
Rhpc_sapply, Rhpc_lapplyLB, Rhpc_apply
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.