| Rhpc_worker_call | R Documentation |
Executes a function on all worker processes and collects the results.
Rhpc_worker_call(cl, FUN, ...,
usequote = ifelse(is.logical(getOption("Rhpc.usequote")),
getOption("Rhpc.usequote"), TRUE))
cl |
external pointer to MPI communicator |
FUN |
function or string naming the function to be called on workers |
... |
arguments to pass to |
usequote |
logical; if |
This function broadcasts a function call to all worker processes and waits for results. Results from all workers are collected and returned.
The function or its name is sent to workers via collective communication only on the first call; subsequent calls with the same function reuse the cached version.
Results collected from all worker processes.
Rhpc_worker_noback, Rhpc_lapply, Rhpc_EvalQ
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.